==> cdi-tck-2.0.6-dist.zip: org/jboss/cdi/tck/interceptors/tests/contract/lifecycleCallback/SheepInterceptor.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.interceptors.tests.contract.lifecycleCallback;

import javax.annotation.PostConstruct;
import javax.interceptor.AroundInvoke;
import javax.interceptor.InvocationContext;

public class SheepInterceptor {
    private static boolean postConstructCalled = false;
    private static boolean aroundInvokeCalled = false;

    @PostConstruct
    public void postConstruct() {
        postConstructCalled = true;
    }

    @AroundInvoke
    public Object aroundInvoke(InvocationContext ctx) throws Exception {
        aroundInvokeCalled = true;
        return ctx.proceed();
    }

    public static boolean isPostConstructCalled() {
        return postConstructCalled;
    }

    public static boolean isAroundInvokeCalled() {
        return aroundInvokeCalled;
    }
}

==> cdi-tck-4.0.5-dist.zip: org/jboss/cdi/tck/interceptors/tests/contract/lifecycleCallback/SheepInterceptor.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.interceptors.tests.contract.lifecycleCallback;

import jakarta.annotation.PostConstruct;
import jakarta.annotation.Priority;
import jakarta.interceptor.AroundInvoke;
import jakarta.interceptor.Interceptor;
import jakarta.interceptor.InvocationContext;

@Interceptor
@SheepBinding
@Priority(1)
public class SheepInterceptor {
    private static boolean postConstructCalled = false;
    private static boolean aroundInvokeCalled = false;

    @PostConstruct
    public void postConstruct() {
        postConstructCalled = true;
    }

    @AroundInvoke
    public Object aroundInvoke(InvocationContext ctx) throws Exception {
        aroundInvokeCalled = true;
        return ctx.proceed();
    }

    public static boolean isPostConstructCalled() {
        return postConstructCalled;
    }

    public static boolean isAroundInvokeCalled() {
        return aroundInvokeCalled;
    }
}
